@@ -102,7 +102,7 @@ exp_raven <- function(X, path = NULL, file.name = NULL, khz.to.hz = TRUE, sound.
   
   mtch <- match(c( "Selection", "View", "Channel", "Begin Time (s)", "End Time (s)", "Low Freq (Hz)", "High Freq (Hz)"), names(X))
   
-  X <- X[,c(mtch[!is.na(mtch)], setdiff(1:ncol(X), mtch))]
+  X <- X[,c(mtch[!is.na(mtch)], base::setdiff(1:ncol(X), mtch))]
   
     
   if(!is.null(sound.file.path))
